@@ -1,6 +1,6 @@
 package Net::WebSocket;
 
-our $VERSION = '0.12-TRIAL1';
+our $VERSION = '0.16-TRIAL1';
 
 =encoding utf-8
 
@@ -38,8 +38,8 @@ Net::WebSocket - WebSocket in Perl
         out => $iof,
     );
 
-    $iof_w->write(
-        Net::WebSocket::Frame::text->new( payload => 'Hello, world' )
+    $iof->write(
+        $ept->create_message( 'text', 'Hello, world' )->to_bytes()
     );
 
     #Determine that $inet can be read from …
@@ -92,9 +92,9 @@ Here are the main modules:
 
 =item L<Net::WebSocket::Handshake::Client>
 
-Logic for handshakes. Every application needs one of these. As of version
-0.5 this handles all headers and can also do
-subprotocol and extension negotiation for you.
+Logic for handshakes. Every application needs one of these.
+This handles all headers and can also negotiate
+subprotocols and extensions for you.
 
 =item L<Net::WebSocket::HTTP_R>
 
@@ -117,12 +117,6 @@ this module, but it will make your life easier.
 Translate WebSocket frames out of a filehandle into useful data for
 your application.
 
-=item Net::WebSocket::Frame::*
-
-Useful for creating raw frames. For data frames (besides continuation),
-these will be your bread-and-butter. See L<Net::WebSocket::Frame::text>
-for sample usage.
-
 =item L<Net::WebSocket::Streamer::Server>
 
 =item L<Net::WebSocket::Streamer::Client>
@@ -130,6 +124,13 @@ for sample usage.
 Useful for sending streamed (fragmented) data rather than
 a full message in a single frame.
 
+=item Net::WebSocket::Frame::*
+
+Useful for creating raw frames. You probably shouldn’t call these
+classes directly; instead, use Endpoint’s C<create_message()> method.
+But if you want to dig deeply, these will be your bread and butter.
+See L<Net::WebSocket::Frame::text> for sample usage.
+
 =back
 
 =head1 IMPLEMENTATION NOTES
@@ -157,11 +158,9 @@ which don’t mask.
 
 This module used to do this with L<Bytes::Random::Secure::Tiny>, but
 that seems like overkill given that the masking is only there to accommodate
-peculiarities of certain proxies. We now just use Perl’s C<rand()>
-built-in.
-
-(You should probably use TLS if cryptographically secure masking is something
-you actually care about?)
+peculiarities of certain proxies. Moreover, TLS is widely available and
+L<free now besides|https://letsencrypt.org>, and it will randomize the data
+stream anyway. So, nowadays we just use Perl’s C<rand()> built-in.
 
 =head2 Text vs. Binary
 
@@ -172,9 +171,9 @@ Recall that in some languages—like JavaScript!—the difference between
 
 CPAN’s L<IO::Framed> provides a straightforward interface for chunking up
 data from byte streams into frames. It also provides a write buffer for
-non-blocking writes, and it retries on EINTR. You don’t have to use it
-(which is why it’s not listed as a requirement), but you’ll need to provide
-a compatible interface if you don’t.
+non-blocking writes, and it (by default) retries on EINTR. You don’t have to
+use it (which is why it’s not listed as a requirement), but you’ll need to
+provide a compatible interface if you don’t.
 
 See the demo scripts that use L<IO::Framed> for an example of when you may
 need a different solution here.
@@ -189,6 +188,7 @@ protocol, all of which Net::WebSocket supports:
 =item * The three reserved bits in each frame’s header.
 (See L<Net::WebSocket::Frame>.) This is used, e.g., in the
 L<permessage-deflate extension|https://tools.ietf.org/html/rfc7692>.
+(See below for its implementation in Net::WebSocket.)
 
 =item * Additional opcodes: 3-7 and 11-15. You’ll need to subclass
 L<Net::WebSocket::Frame> for this, and you will likely want to subclass
@@ -208,14 +208,14 @@ can do in your application.
 
 =head2 permessage-deflate
 
-Net::WebSocket 0.5 introduces support for the permessage-delate extension
-to allow compressed messages over WebSocket. See
-L<Net::WebSocket::PMCE::deflate> for more details.
+Net::WebSocket fully supports the permessage-deflate (compression) extension.
+See L<Net::WebSocket::PMCE::deflate> for details.
 
 =head1 TODO
 
 At this point Net::WebSocket seems to support everything the WebSocket
-protocol can (usefully) do, including compression.
+protocol can (usefully) do, including compression. Please file bug reports
+for any issues that may crop up.
 
 =over
 
@@ -249,7 +249,7 @@ Felipe Gasper (FELIPE)
 
 =head1 COPYRIGHT
 
-Copyright 2017 by L<Gasper Software Consulting|http://gaspersoftware.com>
+Copyright 2018 by L<Gasper Software Consulting|http://gaspersoftware.com>
 
 =head1 LICENSE
 
